ItemKind

Enum ItemKind 

pub enum ItemKind {
    Type(Type),
    Func(FuncTypeId),
    Instance(InterfaceId),
    Component(WorldId),
    Module(ModuleTypeId),
    Value(ValueType),
}
Represents the kind of a component model item.

Note that an item kind is associated with a particular Types collection.

Variants



Type(Type)

The item is a type.



Func(FuncTypeId)

The item is a function.



Instance(InterfaceId)

The item is a component instance.



Component(WorldId)

The item is a component.



Module(ModuleTypeId)

The item is a core module.



Value(ValueType)

The item is a value.

Implementations

Source

impl ItemKind

pub fn ty(&self) -> Type

Gets the type of the item.

Returns None for resource items.

pub fn desc(&self, types: &Types) -> &'static str

Gets a description of the item kind.

pub fn promote(&self) -> Self

Promote function types, instance types, and component types to functions, instances, and components.